#!/usr/bin/env python

import sys
from setuptools import setup
from setuptools.command.test import test as TestCommand

class PyTest(TestCommand):
    user_options = [('pytest-args=', 'a', "Arguments to pass to py.test")]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.pytest_args = []

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.pytest_args)
        sys.exit(errno)


setup(name='dune.perftool',
      version='0.1',
      namespace_packages=['dune'],
      description='Performance optimizing form compiler for dune-pdelab',
      author='Dominic Kempf <dominic.kempf@iwr.uni-heidelberg.de>',
      url='http://conan2.iwr.uni-heidelberg.de/git/dominic/dune-perftool',
      packages=['dune.perftool'],
      install_requires=['dune.testtools', 'sympy'],
      tests_require=['pytest'],
      cmdclass={'test': PyTest},
      entry_points = {
        "console_scripts": [
            "ufl2pdelab = dune.perftool.compile:compile_form",
        ]
    })
